#!/bin/bash
set -Eeuo pipefail

black --check .

